<?php

namespace Tests\Feature;

use App\Models\User;
use Hash;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;

class CompareLensTest extends TestCase
{
    public function test_success_access_to_compare_product_lens_by_admin()
    {
        $user = User::factory()->create([
            'role' => 'admin',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/products/lens/compare-product');
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_success_access_to_compare_product_lens_by_analyst()
    {
        $user = User::factory()->create([
            'role' => 'analyst',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/products/lens/compare-product');
        $user->delete();
        $response->assertStatus(200);
    }

    public function test_access_to_compare_product_lens_by_common()
    {
        $user = User::factory()->create([
            'role' => 'common',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $response = $this->get('/nova/resources/products/lens/compare-product');
        $user->delete();
        $response->assertStatus(403);
    }

    public function test_access_to_compare_product_lens_by_anauthorized()
    {
        $response = $this->get('/nova/resources/products/lens/compare-product');
        $response->assertStatus(302);
    }
}
